@@ -13,7 +13,7 @@ let frozen_lexer = CLexer.get_keyword_state () ;;
 
 
 
-let __coq_plugin_name = "ssrmatching_plugin"
+let __coq_plugin_name = "coq-core.plugins.ssrmatching"
 let _ = Mltop.add_known_module __coq_plugin_name
 
 # 28 "plugins/ssrmatching/g_ssrmatching.mlg"
@@ -117,7 +117,7 @@ let (wit_rpattern, rpattern) = Tacentries.argument_extend ~name:"rpattern"
 # 39 "plugins/ssrmatching/g_ssrmatching.mlg"
                    subst_rpattern 
                                                       );
-                               Tacentries.arg_interp = Tacentries.ArgInterpLegacy (
+                               Tacentries.arg_interp = Tacentries.ArgInterpSimple (
                                                        
 # 37 "plugins/ssrmatching/g_ssrmatching.mlg"
                    interp_rpattern 
@@ -170,7 +170,7 @@ let (wit_cpattern, cpattern) = Tacentries.argument_extend ~name:"cpattern"
 # 61 "plugins/ssrmatching/g_ssrmatching.mlg"
                                                       subst_ssrterm 
                                                       );
-                               Tacentries.arg_interp = Tacentries.ArgInterpLegacy (
+                               Tacentries.arg_interp = Tacentries.ArgInterpSimple (
                                                        
 # 60 "plugins/ssrmatching/g_ssrmatching.mlg"
                       interp_ssrterm 
@@ -244,7 +244,7 @@ let (wit_lcpattern, lcpattern) = Tacentries.argument_extend ~name:"lcpattern"
 # 90 "plugins/ssrmatching/g_ssrmatching.mlg"
                                                       subst_ssrterm 
                                                         );
-                                 Tacentries.arg_interp = Tacentries.ArgInterpLegacy (
+                                 Tacentries.arg_interp = Tacentries.ArgInterpSimple (
                                                          
 # 89 "plugins/ssrmatching/g_ssrmatching.mlg"
                       interp_ssrterm 
